@@ -252,7 +252,7 @@ class UpdateTracker():
     # Updates the record for a particular update
     def update(self, update):
         self.refreshed_update_names.append(update.real_source_name)
-        if not update.real_source_name in self.tracked_updates['updates']:
+        if update.real_source_name not in self.tracked_updates['updates']:
             update_record = {}
             update_record['type'] = update.type
             update_record['since'] = self.today
@@ -271,15 +271,15 @@ class UpdateTracker():
                 self.oldest_since_date = update_record['since']
 
     # Returns the number of days between today and the given date string
-    def get_days_since_date(self, string, date_format):
-        if string == None:
+    def get_days_since_date(self, string: str, date_format: str) -> int:
+        if string is None:
             return 999
         datetime_object = datetime.datetime.strptime(string, date_format)
         days = (datetime.date.today() - datetime_object.date()).days
         return days
 
     # Returns the number of days between today and the given timestamp
-    def get_days_since_timestamp(self, timestamp):
+    def get_days_since_timestamp(self, timestamp: float) -> int:
         if timestamp == 0:
             return 999
         datetime_object = datetime.datetime.fromtimestamp(timestamp)
@@ -292,32 +292,30 @@ class UpdateTracker():
         if os.path.exists("/var/log/apt/history.log"):
             logs = subprocess.getoutput("cat /var/log/apt/history.log")
             for event in logs.split("\n\n"):
-                if not "Upgrade: " in event:
+                if "Upgrade: " not in event:
                     continue
                 end_date = None
-                upgrade = None
                 for line in event.split("\n"):
                     line = line.strip()
                     if line.startswith("End-Date: "):
                         end_date = line.replace("End-Date: ", "")
                         end_date = end_date.split()[0]
-                if end_date != None and (latest_upgrade_date == None or end_date > latest_upgrade_date):
+                if end_date is not None and (latest_upgrade_date is None or end_date > latest_upgrade_date):
                     latest_upgrade_date = end_date
 
-        if latest_upgrade_date == None:
+        if latest_upgrade_date is None:
             try:
                 logs = subprocess.getoutput("zcat /var/log/apt/history.log*gz")
                 for event in logs.split("\n\n"):
-                    if not "Upgrade: " in event:
+                    if "Upgrade: " not in event:
                         continue
                     end_date = None
-                    upgrade = None
                     for line in event.split("\n"):
                         line = line.strip()
                         if line.startswith("End-Date: "):
                             end_date = line.replace("End-Date: ", "")
                             end_date = end_date.split()[0]
-                    if end_date != None and (latest_upgrade_date == None or end_date > latest_upgrade_date):
+                    if end_date is not None and (latest_upgrade_date is None or end_date > latest_upgrade_date):
                         latest_upgrade_date = end_date
             except Exception as e:
                 print("Failed to check compressed APT logs", e)
@@ -374,7 +372,7 @@ class UpdateTracker():
     def record(self):
         # Purge non-refreshed updates
         for name in list(self.tracked_updates['updates'].keys()):
-            if not name in self.refreshed_update_names:
+            if name not in self.refreshed_update_names:
                 del self.tracked_updates['updates'][name]
         # Update the check date
         self.tracked_updates['checked'] = self.today
@@ -534,7 +532,7 @@ class FlatpakUpdate():
         try:
             b = GLib.Bytes.new(json_data["metadata"].encode())
             inst.metadata.load_from_bytes(b, GLib.KeyFileFlags.NONE)
-        except GLib.Error:
+        except GLib.Error as e:
             print("unable to decode op metadata: %s" % e.message)
             pass
 
