@@ -88,7 +88,7 @@ class Assistant:
         vbox_content.pack_start(label, False, False, 6)
         self.vbox_rel_notes.pack_start(vbox_content, False, False, 6)
         link = Gtk.Label()
-        link.set_markup("<a href='https://www.linuxmint.com/rel_%s_%s.php'><b>%s</b></a>" % (self.rel_target_codename, self.current_edition.lower(), _("Release notes for %s") % self.rel_target_name))
+        link.set_markup("<a href='https://www.linuxmint.com/rel_%s.php'><b>%s</b></a>" % (self.rel_target_codename, _("Release notes for %s") % self.rel_target_name))
         self.vbox_rel_notes.pack_start(link, False, False, 6)
         label = Gtk.Label()
         label.set_markup("<i><b>%s</b></i>" % _("Click on the link to open the release notes."))
@@ -110,7 +110,7 @@ class Assistant:
         vbox_content.pack_start(label, False, False, 6)
         self.vbox_new_features.pack_start(vbox_content, False, False, 6)
         link = Gtk.Label()
-        link.set_markup("<a href='https://www.linuxmint.com/rel_%s_%s_whatsnew.php'><b>%s</b></a>" % (self.rel_target_codename, self.current_edition.lower(), _("New features in %s") % self.rel_target_name))
+        link.set_markup("<a href='https://www.linuxmint.com/rel_%s_whatsnew.php'><b>%s</b></a>" % (self.rel_target_codename, _("New features in %s") % self.rel_target_name))
         self.vbox_new_features.pack_start(link, False, False, 6)
         label = Gtk.Label()
         label.set_markup("<i><b>%s</b></i>" % _("Click on the link to browse the new features."))
